# Podch

Program implementation of an abstract board game Podch

Two players place and remove stones from a rectangular board not to repeat a position which has appeared before.

Licensed under a
[Creative Commons Attribution-NonCommercial 4.0 International License](https://creativecommons.org/licenses/by-nc/4.0/).

The accepted pronunciation of the name "podch" is [potx] because of Russian origin ("подх"). In case of inconvenience of
pronouncing [x], it can be replaced by [k]: [potk].

### Installation

`pip install podch`
